box.desktop-preview {
  min-height: 10px;
  padding: 0 4px;
  background-color: black;
}

box.desktop-preview image {
  color: white;
}

box.desktop-preview label {
  color: white;
  font-weight: bold;
  font-size: 6px;
}

widget.window {
  min-width: 150px;
  min-height: 100px;
  border-radius: 6px;
  margin-left: 75px;
  margin-top: 50px;
  background-color: @window_bg_color;
  box-shadow: 0 1px 4px 1px alpha(black, 0.13),
              0 1px 10px 5px alpha(black, 0.09),
              0 3px 16px 8px alpha(black, 0.04),
              0 0 0 1px alpha(black, .05);
}

widget.window .header-bar {
  min-height: 15px;
  box-shadow: inset 0 -1px @headerbar_shade_color;
}

widget.window.front {
  margin-left: -75px;
  margin-top: -25px;
}

widget.window.front .header-bar {
  background-color: @headerbar_bg_color;
}
